==> angular_compiler-0.2.0.tar.gz: test/src/resolve.dart <==
import 'dart:async';

import 'package:analyzer/dart/element/element.dart';
// This import exists only to indicate that AngularDart's metadata is used.
// ignore: unused_import
import 'package:angular/di.dart';
import 'package:build/build.dart';
import 'package:build_test/build_test.dart';

const angular = 'package:angular/angular.dart';

/// Resolves [source] code as-if it is implemented with an AngularDart import.
///
/// Returns the resolved library as `package:test_lib/test_lib.dart`.
Future<LibraryElement> resolveLibrary(String source) async {
  final resolved = await resolveSource(
      '''
      library _test;
      import '$angular';\n\n$source''',
      inputId: new AssetId('test_lib', 'lib/test_lib.dart'));
  return resolved.getLibraryByName('_test');
}

/// Resolves [source] code as-if it is implemented with an AngularDart import.
///
/// Returns first `class` in the file, or by [name] if given.
Future<ClassElement> resolveClass(
  String source, [
  String name,
]) async {
  final library = await resolveLibrary(source);
  return name != null
      ? library.getType(name)
      : library.definingCompilationUnit.types.first;
}

/// Resolve [source] code as-if it is implemented with an AngularDart import.
///
/// Returns first top-level constant field in the file, or by [name] if given.
Future<TopLevelVariableElement> resolveField(
  String source, [
  String name,
]) async {
  final library = await resolveLibrary(source);
  return name == null
      ? library.definingCompilationUnit.topLevelVariables.first
      : library.definingCompilationUnit.topLevelVariables
          .firstWhere((e) => e.name == name);
}

==> angular_compiler-0.2.1.tar.gz: test/src/resolve.dart <==
import 'dart:async';

import 'package:analyzer/dart/element/element.dart';
// This import exists only to indicate that AngularDart's metadata is used.
// ignore: unused_import
import 'package:angular/di.dart';
import 'package:build/build.dart';
import 'package:build_test/build_test.dart';

const angular = 'package:angular/angular.dart';

/// Resolves [source] code as-if it is implemented with an AngularDart import.
///
/// Returns the resolved library as `package:test_lib/test_lib.dart`.
Future<LibraryElement> resolveLibrary(String source) async {
  final resolverDone = new Completer<Null>();
  final resolved = await resolveSource('''
      library _test;
      import '$angular';\n\n$source''',
      inputId: new AssetId('test_lib', 'lib/test_lib.dart'),
      tearDown: resolverDone.future);
  final library = await resolved.findLibraryByName('_test');
  resolverDone.complete();
  return library;
}

/// Resolves [source] code as-if it is implemented with an AngularDart import.
///
/// Returns first `class` in the file, or by [name] if given.
Future<ClassElement> resolveClass(
  String source, [
  String name,
]) async {
  final library = await resolveLibrary(source);
  return name != null
      ? library.getType(name)
      : library.definingCompilationUnit.types.first;
}

/// Resolve [source] code as-if it is implemented with an AngularDart import.
///
/// Returns first top-level constant field in the file, or by [name] if given.
Future<TopLevelVariableElement> resolveField(
  String source, [
  String name,
]) async {
  final library = await resolveLibrary(source);
  return name == null
      ? library.definingCompilationUnit.topLevelVariables.first
      : library.definingCompilationUnit.topLevelVariables
          .firstWhere((e) => e.name == name);
}
